Enum style::rule_tree::CascadeLevel
[−]
[src]
#[repr(u8)]pub enum CascadeLevel { UANormal, PresHints, UserNormal, AuthorNormal, StyleAttributeNormal, SMILOverride, Animations, AuthorImportant, StyleAttributeImportant, UserImportant, UAImportant, Transitions, }
The cascade level these rules are relevant at, as per1.
The order of variants declared here is significant, and must be in ascending order of precedence.
Variants
UANormalNormal User-Agent rules.
PresHintsPresentational hints.
UserNormalUser normal rules.
AuthorNormalAuthor normal rules.
StyleAttributeNormalStyle attribute normal rules.
SMILOverrideSVG SMIL animations.
AnimationsCSS animations and script-generated animations.
AuthorImportantAuthor-supplied important rules.
StyleAttributeImportantStyle attribute important rules.
UserImportantUser important rules.
UAImportantUser-agent important rules.
TransitionsTransitions
NB: If this changes from being last, change from_byte below.
Methods
impl CascadeLevel[src]
pub unsafe fn from_byte(byte: u8) -> Self[src]
Converts a raw byte to a CascadeLevel.
pub fn guard<'a>(
&self,
guards: &'a StylesheetGuards<'a>
) -> &'a SharedRwLockReadGuard<'a>[src]
&self,
guards: &'a StylesheetGuards<'a>
) -> &'a SharedRwLockReadGuard<'a>
Select a lock guard for this level
pub fn is_unique_per_element(&self) -> bool[src]
Returns whether this cascade level is unique per element, in which case we can replace the path in the cascade without fear.
pub fn is_important(&self) -> bool[src]
Returns whether this cascade level represents important rules of some sort.
pub fn importance(&self) -> Importance[src]
Returns the importance relevant for this rule. Pretty similar to
is_important.
pub fn is_animation(&self) -> bool[src]
Returns whether this cascade level represents an animation rules.